@@ -28,12 +28,20 @@ from a `cyclonedx.parser.BaseParser` implementation.
 
 
 def sha1sum(filename: str) -> str:
+    """
+    Generate a SHA1 hash of the provided file.
+
+    Args:
+        filename:
+            Absolute path to file to hash as `str`
+
+    Returns:
+        SHA-1 hash
+    """
     h = hashlib.sha1()
-    b = bytearray(128 * 1024)
-    mv = memoryview(b)
-    with open(filename, 'rb', buffering=0) as f:
-        for n in iter(lambda: f.readinto(mv), 0):
-            h.update(mv[:n])
+    with open(filename, 'rb') as f:
+        for byte_block in iter(lambda: f.read(4096), b""):
+            h.update(byte_block)
     return h.hexdigest()
 
 
@@ -67,9 +75,6 @@ class HashType:
         See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.3/#type_hashType
     """
 
-    _algorithm: HashAlgorithm
-    _value: str
-
     @staticmethod
     def from_composite_str(composite_hash: str):
         """
@@ -84,7 +89,7 @@ class HashType:
         Returns:
             An instance of `HashType` when possible, else `None`.
         """
-        algorithm: HashAlgorithm = None
+        algorithm = None
         parts = composite_hash.split(':')
 
         algorithm_prefix = parts[0].lower()
@@ -110,6 +115,9 @@ class HashType:
     def get_hash_value(self) -> str:
         return self._value
 
+    def __repr__(self):
+        return f'<Hash {self._algorithm.value}:{self._value}>'
+
 
 class ExternalReferenceType(Enum):
     """
@@ -144,17 +152,13 @@ class ExternalReference:
     .. note::
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.3/#type_externalReference
     """
-    _reference_type: ExternalReferenceType
-    _url: str
-    _comment: str
-    _hashes: List[HashType] = []
 
     def __init__(self, reference_type: ExternalReferenceType, url: str, comment: str = None,
-                 hashes: List[HashType] = []):
-        self._reference_type = reference_type
+                 hashes: List[HashType] = None):
+        self._reference_type: ExternalReferenceType = reference_type
         self._url = url
         self._comment = comment
-        self._hashes = hashes
+        self._hashes: List[HashType] = hashes if hashes else []
 
     def add_hash(self, our_hash: HashType):
         """
@@ -201,3 +205,6 @@ class ExternalReference:
             URI as a `str`.
         """
         return self._url
+
+    def __repr__(self):
+        return f'<ExternalReference {self._reference_type.name}, {self._url}> {self._hashes}'
